/* $Id$
 *
 * Lasso - A free implementation of the Liberty Alliance specifications.
 *
 * Copyright (C) 2004-2007 Entr'ouvert
 * http://lasso.entrouvert.org
 *
 * Authors: See AUTHORS file in top-level directory.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __LASSO_LOGIN_PRIVATE_H__
#define __LASSO_LOGIN_PRIVATE_H__

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


#include "config.h"
#include "../xml/saml-2.0/saml2_assertion.h"

struct _LassoLoginPrivate
{
	char *soap_request_msg;
	LassoSaml2Assertion *saml2_assertion;
	char *request_id;
};

LassoSaml2Assertion *lasso_login_get_saml2_assertion(LassoLogin *login);
void lasso_login_set_saml2_assertion(LassoLogin *login, LassoSaml2Assertion *assertion);
const char *lasso_login_get_request_id(LassoLogin *login);
void lasso_login_set_request_id(LassoLogin *login, char *request_id);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __LASSO_LOGIN_PRIVATE_H__ */
